@@ -610,7 +610,7 @@ client_save_yourself_callback (SmcConn   smc_conn,
   gboolean ret;
 
   if (!client_grab_widget)
-    client_grab_widget = gtk_widget_new (GTK_TYPE_WIDGET, NULL);
+    client_grab_widget = gtk_widget_new (GTK_TYPE_INVISIBLE, NULL);
 
   /* The first SaveYourself after registering for the first time
    * is a special case (SM specs 7.2).
@@ -1645,14 +1645,7 @@ gnome_client_set_current_directory (GnomeClient *client,
 }
 
 
-
-/**
- * gnome_client_set_discard_command
- * @client: Pointer to GNOME session client object.
- * @argc: Number of strings in argv.
- * @argv: Vector of strings such as those passed to execv().
- *
- **/
+/* See doc/reference/tmpl/gnome-client.sgml for documentation. */
 
 void
 gnome_client_set_discard_command (GnomeClient *client,
